@@ -5,6 +5,7 @@
 
 use std::convert::TryInto;
 use std::fmt;
+use std::time;
 
 use inspector::ResultInspector;
 use secrecy::ExposeSecret;
@@ -26,12 +27,14 @@ pub(crate) struct Api {
     base: String,
     token: Option<SecretString>,
     user_agent: String,
+    connect_timeout: time::Duration,
 }
 
 impl Api {
     pub(crate) fn new(management: &str, prefix: &str, token: Option<&str>) -> Self {
         let user_agent = format!("{}/{}", env!("CARGO_PKG_NAME"), env!("CARGO_PKG_VERSION"));
         let token = token.map(String::from).map(SecretString::new);
+        let connect_timeout = time::Duration::from_secs(5);
 
         let base = if management.starts_with("http") {
             format!("{}{}", management, prefix)
@@ -47,6 +50,14 @@ impl Api {
             base,
             token,
             user_agent,
+            connect_timeout,
+        }
+    }
+
+    pub(crate) fn connect_timeout(self, connect_timeout: time::Duration) -> Self {
+        Self {
+            connect_timeout,
+            ..self
         }
     }
 
@@ -361,6 +372,7 @@ impl Api {
     fn client(&self) -> reqwest::Result<reqwest::Client> {
         reqwest::Client::builder()
             .user_agent(&self.user_agent)
+            .connect_timeout(self.connect_timeout)
             .build()
     }
 
