@@ -197,7 +197,11 @@ enum Command {
         location: Location,
     },
 
-    #[structopt(about = "Set state availability grade", display_order(40))]
+    #[structopt(
+        about = "Set state availability grade",
+        display_order(40),
+        setting(clap::AppSettings::Hidden)
+    )]
     SetAvailability,
 
     #[structopt(about = "Set cluster as the state owner", display_order(40))]
@@ -216,7 +220,12 @@ enum Command {
         cluster: v0::ClusterName,
     },
 
-    #[structopt(about = "Manually create new volume", aliases = &["create-v", "cv"], display_order(50))]
+    #[structopt(
+        about = "Manually create new volume",
+        aliases = &["create-v", "cv"],
+        display_order(50),
+        setting(clap::AppSettings::Hidden)
+    )]
     CreateVolume {
         #[structopt(help = "State name")]
         state: v0::StateName,
@@ -228,7 +237,12 @@ enum Command {
         fs_type: v0::VolumeFileSystem,
     },
 
-    #[structopt(about = "Manually delete existing volume", aliases = &["delete-v", "dv"], display_order(50))]
+    #[structopt(
+        about = "Manually delete existing volume",
+        aliases = &["delete-v", "dv"],
+        display_order(50),
+        setting(clap::AppSettings::Hidden)
+    )]
     DeleteVolume {
         #[structopt(help = "State name")]
         state: v0::StateName,
@@ -241,7 +255,8 @@ enum Command {
     #[structopt(
         about = "Manually choose primary location for volume",
         aliases = &["set-v", "sv"],
-        display_order(50)
+        display_order(50),
+        setting(clap::AppSettings::Hidden)
     )]
     SetVolume {
         #[structopt(help = "State name")]
@@ -899,15 +914,17 @@ impl StateHub {
     }
 
     async fn check_for_update(&self) {
-        self.check_for_update_helper()
-            .await
-            .and_then(|(current, latest)| {
-                self.inform(format_args!(
-                    "\nNewer version '{}' is available (you have '{}')\n",
-                    latest, current
-                ))
-                .ok()
-            });
+        if !self.json {
+            self.check_for_update_helper()
+                .await
+                .and_then(|(current, latest)| {
+                    self.inform(format_args!(
+                        "\nNewer version '{}' is available (you have '{}')\n",
+                        latest, current
+                    ))
+                    .ok()
+                });
+        }
     }
 
     async fn self_update(&self) -> anyhow::Result<()> {
